ONOS-5863, ONOS-5804 DynamicConfig store and service implementation(create and read supported)

Change-Id: I299a27afe46b87f98d4af79643732e2f1bdc2010
diff --git a/apps/config/src/main/java/org/onosproject/config/DynamicConfigEvent.java b/apps/config/src/main/java/org/onosproject/config/DynamicConfigEvent.java
index bb29b9d..05ed0c4 100755
--- a/apps/config/src/main/java/org/onosproject/config/DynamicConfigEvent.java
+++ b/apps/config/src/main/java/org/onosproject/config/DynamicConfigEvent.java
@@ -16,18 +16,18 @@
 package org.onosproject.config;
 
 
-import org.onosproject.config.model.ResourceIdentifier;
+import org.onosproject.config.model.ResourceId;
 import org.onosproject.event.AbstractEvent;
 
 /**
  * Describes a DynamicConfig change event.
  */
-public class DynamicConfigEvent extends AbstractEvent<DynamicConfigEvent.Type, ResourceIdentifier> {
+public class DynamicConfigEvent extends AbstractEvent<DynamicConfigEvent.Type, ResourceId> {
 
     /**
      * Type of configuration events.
      * A configuration instance could be a leaf node or a subtree,
      * identified by the subject, ResourceIdentifier.
      */
     public enum Type {
         /**
@@ -57,7 +57,7 @@
      * @param type  config node type
      * @param path  config node path
      */
-    public DynamicConfigEvent(Type type, ResourceIdentifier path) {
+    public DynamicConfigEvent(Type type, ResourceId path) {
         super(type, path);
     }
 }
@@ -16,18 +16,18 @@
      * Type of configuration events.
      * A configuration instance could be a leaf node or a subtree,
-     * identified by the subject, ResourceIdentifier.
+     * identified by the subject, ResourceId.
      */
     public enum Type {
\ No newline at end of file